==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QAbstractTextDocumentLayout_Selection_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QAbstractTextDocumentLayout_Selection(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractTextDocumentLayout::Selection")
    QAbstractTextDocumentLayout::Selection *_ptr = reinterpret_cast<QAbstractTextDocumentLayout::Selection *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QAbstractTextDocumentLayout_Selection_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QAbstractTextDocumentLayout::Selection *__qt_this = new(__qtjambi_ptr) QAbstractTextDocumentLayout::Selection();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QAbstractTextDocumentLayout::Selection
void __qt_destruct_QAbstractTextDocumentLayout_Selection(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractTextDocumentLayout::Selection")
    reinterpret_cast<QAbstractTextDocumentLayout::Selection*>(ptr)->~Selection();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractTextDocumentLayout::Selection::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_initialize_1native__Lio_qt_gui_QAbstractTextDocumentLayout_00024Selection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractTextDocumentLayout::Selection::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractTextDocumentLayout_Selection_0, sizeof(QAbstractTextDocumentLayout::Selection), typeid(QAbstractTextDocumentLayout::Selection), false, &deleter_QAbstractTextDocumentLayout_Selection, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAbstractTextDocumentLayout::Selection::operator==(QAbstractTextDocumentLayout::Selection,QAbstractTextDocumentLayout::Selection)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_equals_1native_1cref_1QAbstractTextDocumentLayout_1Selection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID v21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractTextDocumentLayout::Selection::operator==(QAbstractTextDocumentLayout::Selection,QAbstractTextDocumentLayout::Selection)", __qt_this)
        const QAbstractTextDocumentLayout::Selection& __qt_v21 = QtJambiAPI::valueReferenceFromNativeId<QAbstractTextDocumentLayout::Selection>(v21);
        __java_return_value = (*__qt_this) == __qt_v21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_setCursor_1native_1cref_1QTextCursor__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID cursor0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCursor& __qt_cursor0 = QtJambiAPI::valueReferenceFromNativeId<QTextCursor>(cursor0);
        __qt_this->cursor = __qt_cursor0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_cursor_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCursor&  __qt_value = __qt_this->cursor;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_setFormat_1native_1cref_1QTextCharFormat__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID format0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCharFormat& __qt_format0 = QtJambiAPI::valueReferenceFromNativeId<QTextCharFormat>(format0);
        __qt_this->format = __qt_format0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_format_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCharFormat&  __qt_value = __qt_this->format;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QAbstractTextDocumentLayout_Selection(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QAbstractTextDocumentLayout::Selection>("QAbstractTextDocumentLayout::Selection", "io/qt/gui/QAbstractTextDocumentLayout$Selection");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractTextDocumentLayout_Selection, {
        ConstructorInfo(&__qt_construct_QAbstractTextDocumentLayout_Selection_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractTextDocumentLayout_Selection);
    registerMetaType<QAbstractTextDocumentLayout::Selection>("QAbstractTextDocumentLayout::Selection");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QAbstractTextDocumentLayout_Selection_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtCore/QVariant>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextformat.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QAbstractTextDocumentLayout_Selection(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractTextDocumentLayout::Selection")
    QAbstractTextDocumentLayout::Selection *_ptr = reinterpret_cast<QAbstractTextDocumentLayout::Selection *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Selection()
void __qt_construct_QAbstractTextDocumentLayout_Selection(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Selection()")
    Q_UNUSED(__java_arguments)
    QAbstractTextDocumentLayout::Selection *__qt_this = new(__qtjambi_ptr) QAbstractTextDocumentLayout::Selection();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QAbstractTextDocumentLayout::Selection::Selection()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_initialize_1native__Lio_qt_gui_QAbstractTextDocumentLayout_00024Selection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractTextDocumentLayout::Selection::Selection()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractTextDocumentLayout_Selection, sizeof(QAbstractTextDocumentLayout::Selection), typeid(QAbstractTextDocumentLayout::Selection), false, &deleter_QAbstractTextDocumentLayout_Selection, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Selection(QAbstractTextDocumentLayout::Selection)
void __qt_construct_QAbstractTextDocumentLayout_Selection_cref_QAbstractTextDocumentLayout_Selection(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Selection(QAbstractTextDocumentLayout::Selection)")
    jobject other0 = __java_arguments[0].l;
    const QAbstractTextDocumentLayout::Selection& __qt_other0 = qtjambi_cast<const QAbstractTextDocumentLayout::Selection& >(__jni_env, other0);
    QAbstractTextDocumentLayout::Selection *__qt_this = new(__qtjambi_ptr) QAbstractTextDocumentLayout::Selection(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QAbstractTextDocumentLayout::Selection::Selection(QAbstractTextDocumentLayout::Selection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_initialize_1native__Lio_qt_gui_QAbstractTextDocumentLayout_00024Selection_2Lio_qt_gui_QAbstractTextDocumentLayout_00024Selection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractTextDocumentLayout::Selection::Selection(QAbstractTextDocumentLayout::Selection)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractTextDocumentLayout_Selection_cref_QAbstractTextDocumentLayout_Selection, sizeof(QAbstractTextDocumentLayout::Selection), typeid(QAbstractTextDocumentLayout::Selection), false, &deleter_QAbstractTextDocumentLayout_Selection, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Selection{QTextCursor,QTextCharFormat}
void __qt_construct_QAbstractTextDocumentLayout_Selection_QTextCursor_QTextCharFormat(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Selection{QTextCursor,QTextCharFormat}")
    jobject cursor0 = __java_arguments[0].l;
    QTextCursor __qt_cursor0 = qtjambi_cast<QTextCursor >(__jni_env, cursor0);
    jobject format1 = __java_arguments[1].l;
    QTextCharFormat __qt_format1 = qtjambi_cast<QTextCharFormat >(__jni_env, format1);
    QAbstractTextDocumentLayout::Selection *__qt_this = new(__qtjambi_ptr) QAbstractTextDocumentLayout::Selection{__qt_cursor0, __qt_format1};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QAbstractTextDocumentLayout::Selection::Selection{QTextCursor,QTextCharFormat}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_initialize_1native__Lio_qt_gui_QAbstractTextDocumentLayout_00024Selection_2Lio_qt_gui_QTextCursor_2Lio_qt_gui_QTextCharFormat_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject cursor0,
 jobject format1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractTextDocumentLayout::Selection::Selection{QTextCursor,QTextCharFormat}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = cursor0;
        arguments[1].l = format1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractTextDocumentLayout_Selection_QTextCursor_QTextCharFormat, sizeof(QAbstractTextDocumentLayout::Selection), typeid(QAbstractTextDocumentLayout::Selection), false, &deleter_QAbstractTextDocumentLayout_Selection, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAbstractTextDocumentLayout::Selection
void __qt_destruct_QAbstractTextDocumentLayout_Selection(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractTextDocumentLayout::Selection")
    reinterpret_cast<QAbstractTextDocumentLayout::Selection*>(ptr)->~Selection();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractTextDocumentLayout::Selection::operator==(QAbstractTextDocumentLayout::Selection,QAbstractTextDocumentLayout::Selection)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_equals_1native_1cref_1QAbstractTextDocumentLayout_1Selection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID v21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractTextDocumentLayout::Selection::operator==(QAbstractTextDocumentLayout::Selection,QAbstractTextDocumentLayout::Selection)", __qt_this)
        const QAbstractTextDocumentLayout::Selection& __qt_v21 = QtJambiAPI::valueReferenceFromNativeId<QAbstractTextDocumentLayout::Selection>(v21);
        __java_return_value = (*__qt_this) == __qt_v21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_setCursor_1native_1cref_1QTextCursor__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID cursor0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCursor& __qt_cursor0 = QtJambiAPI::valueReferenceFromNativeId<QTextCursor>(cursor0);
        __qt_this->cursor = __qt_cursor0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_cursor_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCursor&  __qt_value = __qt_this->cursor;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_setFormat_1native_1cref_1QTextCharFormat__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID format0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCharFormat& __qt_format0 = QtJambiAPI::valueReferenceFromNativeId<QTextCharFormat>(format0);
        __qt_this->format = __qt_format0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_format_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextCharFormat&  __qt_value = __qt_this->format;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractTextDocumentLayout_00024Selection_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QAbstractTextDocumentLayout::Selection *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractTextDocumentLayout::Selection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QAbstractTextDocumentLayout_Selection(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QAbstractTextDocumentLayout::Selection>("QAbstractTextDocumentLayout::Selection", "io/qt/gui/QAbstractTextDocumentLayout$Selection");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractTextDocumentLayout_Selection, {
        ConstructorInfo(&__qt_construct_QAbstractTextDocumentLayout_Selection, nullptr)
       ,ConstructorInfo(&__qt_construct_QAbstractTextDocumentLayout_Selection_cref_QAbstractTextDocumentLayout_Selection, "Lio/qt/gui/QAbstractTextDocumentLayout$Selection;")
       ,ConstructorInfo(&__qt_construct_QAbstractTextDocumentLayout_Selection_QTextCursor_QTextCharFormat, "Lio/qt/gui/QTextCursor;Lio/qt/gui/QTextCharFormat;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractTextDocumentLayout_Selection);
    registerMetaType<QAbstractTextDocumentLayout::Selection>("QAbstractTextDocumentLayout::Selection");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
